@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.75';
+our $VERSION = '0.76';
 
 use Dist::Zilla 6.0;
 
@@ -148,7 +148,7 @@ has _has_xs => (
 has pod_coverage_class => (
     is        => 'ro',
     isa       => 'Str',
-    predicate => '_has_coverage_class',
+    predicate => '_has_pod_coverage_class',
 );
 
 has pod_coverage_skip => (
@@ -157,7 +157,7 @@ has pod_coverage_skip => (
     isa      => 'ArrayRef[Str]',
     required => 1,
     handles  => {
-        _has_coverage_skip => 'count',
+        _has_pod_coverage_skip => 'count',
     },
 );
 
@@ -167,7 +167,7 @@ has pod_coverage_trustme => (
     isa      => 'ArrayRef[Str]',
     required => 1,
     handles  => {
-        _has_coverage_trustme => 'count',
+        _has_pod_coverage_trustme => 'count',
     },
 );
 
@@ -177,7 +177,7 @@ has pod_coverage_also_private => (
     isa      => 'ArrayRef[Str]',
     required => 1,
     handles  => {
-        _has_coverage_also_private => 'count',
+        _has_pod_coverage_also_private => 'count',
     },
 );
 
@@ -382,17 +382,21 @@ sub _copy_files_from_build_plugin {
 # These are files which are generated as part of the build process and then
 # copied back into the git repo and checked in.
 sub _build_files_to_copy_from_build {
-    [
-        qw(
-            Build.PL
-            CONTRIBUTING.md
-            LICENSE
-            Makefile.PL
-            README.md
-            cpanfile
-            ppport.h
-            )
-    ];
+    my $self = shift;
+
+    my @files = qw(
+        CONTRIBUTING.md
+        LICENSE
+        README.md
+        cpanfile
+    );
+
+    push @files,
+        $self->make_tool eq 'MakeMaker' ? 'Makefile.PL' : 'Build.PL';
+
+    push @files, 'ppport.h' if $self->_has_xs;
+
+    return \@files;
 }
 
 sub _github_plugins {
@@ -560,22 +564,22 @@ sub _pod_test_plugins {
         [
             'Test::Pod::Coverage::Configurable' => {
                 (
-                    $self->_has_coverage_also_private
+                    $self->_has_pod_coverage_also_private
                     ? ( also_private => $self->pod_coverage_also_private )
                     : ()
                 ),
                 (
-                    $self->_has_coverage_skip
+                    $self->_has_pod_coverage_skip
                     ? ( skip => $self->pod_coverage_skip )
                     : ()
                 ),
                 (
-                    $self->_has_coverage_trustme
+                    $self->_has_pod_coverage_trustme
                     ? ( trustme => $self->pod_coverage_trustme )
                     : ()
                 ),
                 (
-                    $self->_has_coverage_class
+                    $self->_has_pod_coverage_class
                     ? ( class => $self->pod_coverage_class )
                     : ()
                 ),
@@ -780,7 +784,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.75
+version 0.76
 
 =head1 SYNOPSIS
 
